==> vtigercrm-5.3.0p0.tgz: modules/Campaigns/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Campaigns
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30 Last change : 2007-10-10
*  Author       : Rafael Soler
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx

 ********************************************************************************/

$mod_strings = Array(
// Added in release 5.0
'LBL_CAMPAIGN_INFORMATION'=>'Información de Campaña',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional',
'LBL_EXPECTATIONS_AND_ACTUALS'=>'Expectativa y Real',

'Campaign Name'=>'Nombre de Campaña',
'Campaign Type'=>'Tipo de Campaña',
'Campaign Status'=>'Situación de Campaña',
'Campaign ID'=>'ID de Campaña',
'Expected Close Date'=>'Fecha Estimada de Fin',
'Expected Revenue'=>'Beneficio Estimado',
'Budget Cost'=>'Costo Estimado',
'Actual Cost'=>'Costo Real',
'Expected Response'=>'Respuesta Estimada',
'Assigned To'=>'Asignado a',
'Num Sent'=>'Número de Envíos',
'Created Time'=>'Creado',
'Modified Time'=>'Modificado',
'Description'=>'Descripción',
'Product'=>'Producto',
'Target Audience'=>'Público Objetivo',
'TargetSize'=>'Cantidad Objetivo',
'Sponsor'=>'Patrocinador',

'Expected Sales Count'=>'Estimación de Ventas',
'Expected Response Count'=>'Estimación de Respuestas',
'Expected ROI'=>'Estimación de ROI',

'Actual Sales Count'=>'Ventas',
'Actual Response Count'=>'Respuestas',
'Actual ROI'=>'Retorno de Inversión',
'Select One'=>'Elija uno',
'LBL_LOAD_LIST'=>'Cargar Listado',

//Added for existing Picklist Entries

'Conference'=>'Conferencia',
'Webinar'=>'Webinar',
'Trade Show'=>'Feria',				    
'Public Relations'=>'Relaciones Públicas',
'Partners'=>'Socios',
'Referral Program'=>'Programa de Referidos',
'Advertisement'=>'Publicidad',
'Banner Ads'=>'Banners',
'Direct Mail'=>'Mailing',
'Email'=>'Emailing',
'Telemarketing'=>'Telemarketing',
'Others'=>'Otros',

'Planning'=>'Planeada',						      	    
'Active'=>'Activa',	
'Inactive'=>'Inactiva',
'Complete'=>'Completa',
'Cancelled'=>'Cancelada',							      

'Excellent'=>'Excelente',
'Good'=>'Buena',
'Average'=>'Normal',
'Poor'=>'Pobre',
			      
//Module Sequence Numbering
'Campaign No'=>'Núm. Campaña',
// END

// status fields 
'--None--'=>'--Ninguno--',
'Contacted - Successful' => 'Respuesta - Satisfactoria',
'Contacted - Unsuccessful' => 'Respuesta - Insatisfactoria',
'Contacted - Never Contact Again' => 'Respuesta - No volver a contactar'

);

?>

==> vtigercrm-5.4.0.tgz: modules/Campaigns/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Campaigns
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Odin Consultores S de RL de CV
*  Last change  : 2012-02-28
 ********************************************************************************/

$mod_strings = Array(
// Added in release 5.0
'LBL_CAMPAIGN_INFORMATION'=>'Información de Campaña',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional',
'LBL_EXPECTATIONS_AND_ACTUALS'=>'Expectativa y Real',

'Campaign Name'=>'Nombre de Campaña',
'Campaign Type'=>'Tipo de Campaña',
'Campaign Status'=>'Situación de Campaña',
'Campaign ID'=>'ID de Campaña',
'Expected Close Date'=>'Fecha Estimada de Fin',
'Expected Revenue'=>'Beneficio Estimado',
'Budget Cost'=>'Costo Estimado',
'Actual Cost'=>'Costo Real',
'Expected Response'=>'Respuesta Estimada',
'Assigned To'=>'Asignado a',
'Num Sent'=>'Número de Envíos',
'Created Time'=>'Creado',
'Modified Time'=>'Modificado',
'Description'=>'Descripción',
'Product'=>'Producto',
'Target Audience'=>'Público Objetivo',
'TargetSize'=>'Cantidad Objetivo',
'Sponsor'=>'Patrocinador',

'Expected Sales Count'=>'Estimación de Ventas',
'Expected Response Count'=>'Estimación de Respuestas',
'Expected ROI'=>'Estimación de ROI',

'Actual Sales Count'=>'Ventas',
'Actual Response Count'=>'Respuestas',
'Actual ROI'=>'Retorno de Inversión',
'Select One'=>'Elija uno',
'LBL_LOAD_LIST'=>'Cargar Listado',

//Added for existing Picklist Entries

'Conference'=>'Conferencia',
'Webinar'=>'Webinar',
'Trade Show'=>'Feria',				    
'Public Relations'=>'Relaciones Públicas',
'Partners'=>'Socios',
'Referral Program'=>'Programa de Referidos',
'Advertisement'=>'Publicidad',
'Banner Ads'=>'Banners',
'Direct Mail'=>'Mailing',
'Email'=>'Emailing',
'Telemarketing'=>'Telemarketing',
'Others'=>'Otros',

'Planning'=>'Planeada',						      	    
'Active'=>'Activa',	
'Inactive'=>'Inactiva',
'Complete'=>'Completa',
'Cancelled'=>'Cancelada',							      

'Excellent'=>'Excelente',
'Good'=>'Buena',
'Average'=>'Normal',
'Poor'=>'Pobre',
			      
//Module Sequence Numbering
'Campaign No'=>'Núm. Campaña',
// END

// status fields 
'--None--'=>'--Ninguno--',
'Contacted - Successful' => 'Respuesta - Satisfactoria',
'Contacted - Unsuccessful' => 'Respuesta - Insatisfactoria',
'Contacted - Never Contact Again' => 'Respuesta - No volver a contactar',
'Campaigns ID' => 'Id Campaña',
);

?>
